
::: polaris.evaluate.BenchmarkResults

---

::: polaris.evaluate.MetricInfo

::: polaris.evaluate._metric.absolute_average_fold_error

---

::: polaris.evaluate.Metric
    options: 
        filters: ["!^_", "!fn", "!is_multitask", "!y_type"]

---